==> d4storagehub4R_0.4.tar.gz: d4storagehub4R/README.md <==
[![Build Status](https://github.com/eblondel/d4storagehub4R/actions/workflows/r-cmd-check.yml/badge.svg?branch=master)](https://github.com/eblondel/d4storagehub4R/actions/workflows/r-cmd-check.yml)
[![CRAN_Status_Badge](http://www.r-pkg.org/badges/version/d4storagehub4R)](https://cran.r-project.org/package=d4storagehub4R)
[![cran checks](https://cranchecks.info/badges/worst/d4storagehub4R)](https://cran.r-project.org/web/checks/check_results_d4storagehub4R.html)
[![Github_Status_Badge](https://img.shields.io/badge/Github-0.4-blue.svg)](https://github.com/eblondel/d4storagehub4R)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.5496998.svg)](https://doi.org/10.5281/zenodo.5496998)

**d4storagehub4R – R Interface to 'D4Science' 'StorageHub' API**

`d4storagehub4R` provides an interface to 'D4Science' 'StorageHub' API (<https://dev.d4science.org/>). It allows to get user profile, and perform actions over the 'StorageHub' (workspace) including creation of folders, files management (upload/update/deletion/sharing), and listing of stored resources.

## Sponsors

The following projects have contributed to the development of ``d4storagehub4R``:

<a href="https://blue-cloud.org/"><img height=100 width=300 src="https://www.blue-cloud.org/sites/all/themes/arcadia/logo.png"/></a>

_Blue-Cloud has received funding from the European Union's Horizon programme call BG-07-2019-2020, topic: [A] 2019 - Blue Cloud services, Grant Agreement No.862409._

## Citation

We thank in advance people that use ``d4storagehub4R`` for citing it in their work / publication(s). For this, please use the citation provided at this link [![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.5496998.svg)](https://doi.org/10.5281/zenodo.5496998)

In case of a missing feature, [create a ticket](https://github.com/eblondel/d4storagehub4R/issues/new).

For more information, or if you are interested in funding this R project or to contribute to it, do not hesitate to contact me by [e-mail](mailto:emmanuel.blondel1@gmail.com)

==> d4storagehub4R_0.4-1.tar.gz: d4storagehub4R/README.md <==
[![Build Status](https://github.com/eblondel/d4storagehub4R/actions/workflows/r-cmd-check.yml/badge.svg?branch=master)](https://github.com/eblondel/d4storagehub4R/actions/workflows/r-cmd-check.yml)
[![CRAN_Status_Badge](http://www.r-pkg.org/badges/version/d4storagehub4R)](https://cran.r-project.org/package=d4storagehub4R)
[![cran checks](https://cranchecks.info/badges/worst/d4storagehub4R)](https://cran.r-project.org/web/checks/check_results_d4storagehub4R.html)
[![Github_Status_Badge](https://img.shields.io/badge/Github-0.4--1-blue.svg)](https://github.com/eblondel/d4storagehub4R)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.5496998.svg)](https://doi.org/10.5281/zenodo.5496998)

**d4storagehub4R – R Interface to 'D4Science' 'StorageHub' API**

`d4storagehub4R` provides an interface to 'D4Science' 'StorageHub' API (<https://dev.d4science.org/>). It allows to get user profile, and perform actions over the 'StorageHub' (workspace) including creation of folders, files management (upload/update/deletion/sharing), and listing of stored resources.

## Sponsors

The following projects have contributed to the development of ``d4storagehub4R``:

<a href="https://blue-cloud.org/"><img height=100 width=300 src="https://www.blue-cloud.org/sites/all/themes/arcadia/logo.png"/></a>

_Blue-Cloud has received funding from the European Union's Horizon programme call BG-07-2019-2020, topic: [A] 2019 - Blue Cloud services, Grant Agreement No.862409._

## Citation

We thank in advance people that use ``d4storagehub4R`` for citing it in their work / publication(s). For this, please use the citation provided at this link [![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.5496998.svg)](https://doi.org/10.5281/zenodo.5496998)

In case of a missing feature, [create a ticket](https://github.com/eblondel/d4storagehub4R/issues/new).

For more information, or if you are interested in funding this R project or to contribute to it, do not hesitate to contact me by [e-mail](mailto:emmanuel.blondel1@gmail.com)
